import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class CountLastPatternMatchesResult(ResultBase):
    def __init__(self, result, successMessage, errorMessage):
        ResultBase.__init__(
            self, result["matches"] != -1 and result["errorCode"] == 0, successMessage, errorMessage)

        self.matches = result["matches"]

        if self.success is True:
            return

        self.message = self.getMessageForErrorCode(self.message, result["errorCode"])



import sys
import json

from testwizard.commands_core import CommandBase
from .FindPatternResult import FindPatternResult

class FindPatternCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "FindPattern")
    
    def execute(self, filename, mode):
        if filename is None:
            raise Exception("filename is required")
        if mode is None:
            raise Exception("mode is required")

        requestObj = [filename, mode]

        result = self.executeCommand(requestObj, "Could not execute command")        

        return FindPatternResult(result, "FindPattern was successful", "FindPattern failed")   


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class SaveFileResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        if "saved" in result:
            result["ok"] = result["saved"] is True

        ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage)

        self.filePath = result["filePath"]

        if self.success is True:
            return

        if "errorCode" in result:
            self.message = self.getMessageForErrorCode(self.message, result["errorCode"])
        else:
            self.message = self.message + result["errorMessage"]



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkResult import OkResult


class ClearOnScreenDisplayCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "ClearOnScreenDisplay")

    def execute(self, osdArea):
        if osdArea is not None:
            requestObj = [osdArea]

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkResult(result, "ClearOnScreenDisplay was successful", "ClearOnScreenDisplay failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult


class LoadReferenceBitmapCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "LoadReferenceBitmap")

    def execute(self, filename):
        if filename is None:
            raise Exception("filename is required")

        requestObj = [filename]

        result = self.executeCommand(requestObj, "Could not execute command")

        return SimpleResult(result, "LoadReferenceBitmap was successful", "LoadReferenceBitmap failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .GetVideoResolutionResult import GetVideoResolutionResult


class GetVideoResolutionCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "GetVideoResolution")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj, "Could not execute command")

        return GetVideoResolutionResult(result, "GetVideoResolution was successful", "GetVideoResolution failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .SaveFileResult import SaveFileResult

class StartRecordingCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "StartRecording")
    
    def execute(self, filename):
        if filename is None:
            raise Exception("filename is required")

        requestObj = [filename]

        result = self.executeCommand(requestObj, "Could not execute command")

        return SaveFileResult(result, "StartRecording was successful", "StartRecording failed")


import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class FindAllPatternLocationsResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(
            self, result["errorCode"] == 0, successMessage, failMessage)

        self.matches = result["matches"]
        self.numberOfMatches = result["numberOfMatches"]

        if self.success is True:
            return

        self.message = self.getMessageForErrorCode(self.message, result["errorCode"])
